Installation
============

At the command line::

    $ easy_install infoblox_netmri

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv infoblox_netmri
    $ pip install infoblox_netmri
